summaryrefslogtreecommitdiffstats
path: root/konversation/src/identity.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/identity.cpp')
-rw-r--r--konversation/src/identity.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/konversation/src/identity.cpp b/konversation/src/identity.cpp
index 01697dd..30fea93 100644
--- a/konversation/src/identity.cpp
+++ b/konversation/src/identity.cpp
@@ -15,7 +15,7 @@
#include "identity.h"
#include "irccharsets.h"
-#include <qtextcodec.h>
+#include <tqtextcodec.h>
#include <kdebug.h>
#include <kglobal.h>
@@ -98,46 +98,46 @@ void Identity::copy(const Identity& original)
setCodecName(original.getCodecName());
}
-void Identity::setName(const QString& newName) { name=newName; }
-QString Identity::getName() const { return name; }
+void Identity::setName(const TQString& newName) { name=newName; }
+TQString Identity::getName() const { return name; }
-void Identity::setRealName(const QString& name) { realName=name; }
-QString Identity::getRealName() const { return realName; }
-void Identity::setIdent(const QString& newIdent) { ident=newIdent; }
-QString Identity::getIdent() const { return ident; }
+void Identity::setRealName(const TQString& name) { realName=name; }
+TQString Identity::getRealName() const { return realName; }
+void Identity::setIdent(const TQString& newIdent) { ident=newIdent; }
+TQString Identity::getIdent() const { return ident; }
-void Identity::setNickname(uint index,const QString& newName) { nicknameList[index]=newName; }
+void Identity::setNickname(uint index,const TQString& newName) { nicknameList[index]=newName; }
-QString Identity::getNickname(uint index) const
+TQString Identity::getNickname(uint index) const
{
if(index < nicknameList.count())
return nicknameList[index];
else
- return QString();
+ return TQString();
}
-void Identity::setBot(const QString& newBot) { bot=newBot; }
-QString Identity::getBot() const { return bot; }
+void Identity::setBot(const TQString& newBot) { bot=newBot; }
+TQString Identity::getBot() const { return bot; }
-void Identity::setPassword(const QString& newPassword) { password=newPassword; }
-QString Identity::getPassword() const { return password; }
+void Identity::setPassword(const TQString& newPassword) { password=newPassword; }
+TQString Identity::getPassword() const { return password; }
-void Identity::setQuitReason(const QString& reason) { quitReason=reason; }
-QString Identity::getQuitReason() const { return quitReason; }
-void Identity::setPartReason(const QString& reason) { partReason=reason; }
-QString Identity::getPartReason() const { return partReason; }
-void Identity::setKickReason(const QString& reason) { kickReason=reason; }
-QString Identity::getKickReason() const { return kickReason; }
+void Identity::setQuitReason(const TQString& reason) { quitReason=reason; }
+TQString Identity::getQuitReason() const { return quitReason; }
+void Identity::setPartReason(const TQString& reason) { partReason=reason; }
+TQString Identity::getPartReason() const { return partReason; }
+void Identity::setKickReason(const TQString& reason) { kickReason=reason; }
+TQString Identity::getKickReason() const { return kickReason; }
void Identity::setInsertRememberLineOnAway(bool state) { insertRememberLineOnAway = state; }
bool Identity::getInsertRememberLineOnAway() const { return insertRememberLineOnAway; }
void Identity::setShowAwayMessage(bool state) { showAwayMessages=state; }
bool Identity::getShowAwayMessage() const { return showAwayMessages; }
-void Identity::setAwayMessage(const QString& message) { awayMessage=message; }
-QString Identity::getAwayMessage() const { return awayMessage; }
-void Identity::setReturnMessage(const QString& message) { returnMessage=message; }
-QString Identity::getReturnMessage() const { return returnMessage; }
+void Identity::setAwayMessage(const TQString& message) { awayMessage=message; }
+TQString Identity::getAwayMessage() const { return awayMessage; }
+void Identity::setReturnMessage(const TQString& message) { returnMessage=message; }
+TQString Identity::getReturnMessage() const { return returnMessage; }
void Identity::setAutomaticAway(bool automaticAway) { m_automaticAway = automaticAway; }
bool Identity::getAutomaticAway() const { return m_automaticAway; }
@@ -146,26 +146,26 @@ int Identity::getAwayInactivity() const { return m_awayInactivity
void Identity::setAutomaticUnaway(bool automaticUnaway) { m_automaticUnaway = automaticUnaway; }
bool Identity::getAutomaticUnaway() const { return m_automaticUnaway; }
-void Identity::setNicknameList(const QStringList& newList)
+void Identity::setNicknameList(const TQStringList& newList)
{
nicknameList.clear();
nicknameList = newList;
}
-QStringList Identity::getNicknameList() const { return nicknameList; }
+TQStringList Identity::getNicknameList() const { return nicknameList; }
-QString Identity::getShellCommand() const { return m_shellCommand;}
-void Identity::setShellCommand(const QString& command) { m_shellCommand=command;}
+TQString Identity::getShellCommand() const { return m_shellCommand;}
+void Identity::setShellCommand(const TQString& command) { m_shellCommand=command;}
-QTextCodec* Identity::getCodec() const { return m_codec; }
-QString Identity::getCodecName() const { return m_codecName; }
-void Identity::setCodecName(const QString &newCodecName)
+TQTextCodec* Identity::getCodec() const { return m_codec; }
+TQString Identity::getCodecName() const { return m_codecName; }
+void Identity::setCodecName(const TQString &newCodecName)
{
// NOTE: codecName should be based on KCharsets::availableEncodingNames() / descriptiveEncodingNames()
// We can get a QTextCodec from QString based on them, but can't do the reverse of that.
// never set an empty or borked codec!
- QString codecName=newCodecName.lower();
+ TQString codecName=newCodecName.lower();
if(!Konversation::IRCCharsets::self()->isValidEncoding(codecName))
codecName=Konversation::IRCCharsets::self()->encodingForLocale();
@@ -173,5 +173,5 @@ void Identity::setCodecName(const QString &newCodecName)
m_codec=Konversation::IRCCharsets::self()->codecForName(codecName);
}
-QString Identity::getAwayNick() const { return awayNick; }
-void Identity::setAwayNick(const QString& n) { awayNick = n; }
+TQString Identity::getAwayNick() const { return awayNick; }
+void Identity::setAwayNick(const TQString& n) { awayNick = n; }
@@ -146,26 +146,26 @@ int Identity::getAwayInactivity() const { return m_awayInactivity
{
// NOTE: codecName should be based on KCharsets::availableEncodingNames() / descriptiveEncodingNames()
- // We can get a QTextCodec from QString based on them, but can't do the reverse of that.
+ // We can get a TQTextCodec from TQString based on them, but can't do the reverse of that.
// never set an empty or borked codec!